__title__ = 'pur'
__description__ = 'Update packages in a requirements.txt file to latest versions.'
__url__ = 'https://github.com/alanhamlett/pip-update-requirements'
__version_info__ = ('3', '0', '1')
__version__ = '.'.join(__version_info__)
__author__ = 'Alan Hamlett'
__author_email__ = 'alan.hamlett@gmail.com'
__license__ = 'BSD'
__copyright__ = 'Copyright 2016 Alan Hamlett'
